@@ -197,16 +197,22 @@ return FALSE;
 static gboolean
 mydicto_about_cb()
 {
+gchar *desc;
+
+desc=g_strdup_printf("Dictation application\nUsing libdicto: %s", dicto_get_version_string());
+
 he_about_dialog_present(GTK_WINDOW(mapp.window),
     "myDicto",
     "mydicto",
     VERSION,
-    "Dictation application",
+    desc,
     "myDicto is free software, GPLv2\n"
     "Copyright 2010-2011 Kaj-Michael Lang <milang@tal.org>",
     URL_MYDICTO,
     URL_BUGS,
     PAYPAL_URL);
+
+g_free(desc);
 return TRUE;
 }
 
